@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -34,6 +34,7 @@
 #include <openvdb/Exceptions.h>
 #include "Math.h"
 #include "Tuple.h"
+#include <algorithm>
 #include <cmath>
 #include <type_traits>
 
@@ -49,8 +50,8 @@ template<typename T>
 class Vec3: public Tuple<3, T>
 {
 public:
-    typedef T value_type;
-    typedef T ValueType;
+    using value_type = T;
+    using ValueType = T;
 
     /// Trivial constructor, the vector is NOT initialized
     Vec3() {}
@@ -260,7 +261,7 @@ public:
         return *this;
     }
 
-    /// Returns v, where \f$v_i *= scalar\f$ for \f$i \in [0, 2]\f$
+    /// Multiply each element of this vector by @a scalar.
     template <typename S>
     const Vec3<T> &operator*=(S scalar)
     {
@@ -270,7 +271,7 @@ public:
         return *this;
     }
 
-    /// Returns v0, where \f$v0_i *= v1_i\f$ for \f$i \in [0, 2]\f$
+    /// Multiply each element of this vector by the corresponding element of the given vector.
     template <typename S>
     const Vec3<T> &operator*=(const Vec3<S> &v1)
     {
@@ -280,7 +281,7 @@ public:
         return *this;
     }
 
-    /// Returns v, where \f$v_i /= scalar\f$ for \f$i \in [0, 2]\f$
+    /// Divide each element of this vector by @a scalar.
     template <typename S>
     const Vec3<T> &operator/=(S scalar)
     {
@@ -290,7 +291,7 @@ public:
         return *this;
     }
 
-    /// Returns v0, where \f$v0_i /= v1_i\f$ for \f$i \in [0, 2]\f$
+    /// Divide each element of this vector by the corresponding element of the given vector.
     template <typename S>
     const Vec3<T> &operator/=(const Vec3<S> &v1)
     {
@@ -300,7 +301,7 @@ public:
         return *this;
     }
 
-    /// Returns v, where \f$v_i += scalar\f$ for \f$i \in [0, 2]\f$
+    /// Add @a scalar to each element of this vector.
     template <typename S>
     const Vec3<T> &operator+=(S scalar)
     {
@@ -310,7 +311,7 @@ public:
         return *this;
     }
 
-    /// Returns v0, where \f$v0_i += v1_i\f$ for \f$i \in [0, 2]\f$
+    /// Add each element of the given vector to the corresponding element of this vector.
     template <typename S>
     const Vec3<T> &operator+=(const Vec3<S> &v1)
     {
@@ -320,7 +321,7 @@ public:
         return *this;
     }
 
-    /// Returns v, where \f$v_i += scalar\f$ for \f$i \in [0, 2]\f$
+    /// Subtract @a scalar from each element of this vector.
     template <typename S>
     const Vec3<T> &operator-=(S scalar)
     {
@@ -330,7 +331,7 @@ public:
         return *this;
     }
 
-    /// Returns v0, where \f$v0_i -= v1_i\f$ for \f$i \in [0, 2]\f$
+    /// Subtract each element of the given vector from the corresponding element of this vector.
     template <typename S>
     const Vec3<T> &operator-=(const Vec3<S> &v1)
     {
@@ -494,11 +495,11 @@ inline bool operator==(const Vec3<T0> &v0, const Vec3<T1> &v1)
 template <typename T0, typename T1>
 inline bool operator!=(const Vec3<T0> &v0, const Vec3<T1> &v1) { return !(v0==v1); }
 
-/// Returns V, where \f$V_i = v_i * scalar\f$ for \f$i \in [0, 2]\f$
+/// Multiply each element of the given vector by @a scalar and return the result.
 template <typename S, typename T>
 inline Vec3<typename promote<S, T>::type> operator*(S scalar, const Vec3<T> &v) { return v*scalar; }
 
-/// Returns V, where \f$V_i = v_i * scalar\f$ for \f$i \in [0, 2]\f$
+/// Multiply each element of the given vector by @a scalar and return the result.
 template <typename S, typename T>
 inline Vec3<typename promote<S, T>::type> operator*(const Vec3<T> &v, S scalar)
 {
@@ -507,7 +508,7 @@ inline Vec3<typename promote<S, T>::type> operator*(const Vec3<T> &v, S scalar)
     return result;
 }
 
-/// Returns V, where \f$V_i = v0_i * v1_i\f$ for \f$i \in [0, 2]\f$
+/// Multiply corresponding elements of @a v0 and @a v1 and return the result.
 template <typename T0, typename T1>
 inline Vec3<typename promote<T0, T1>::type> operator*(const Vec3<T0> &v0, const Vec3<T1> &v1)
 {
@@ -516,14 +517,14 @@ inline Vec3<typename promote<T0, T1>::type> operator*(const Vec3<T0> &v0, const
 }
 
 
-/// Returns V, where \f$V_i = scalar / v_i\f$ for \f$i \in [0, 2]\f$
+/// Divide @a scalar by each element of the given vector and return the result.
 template <typename S, typename T>
 inline Vec3<typename promote<S, T>::type> operator/(S scalar, const Vec3<T> &v)
 {
     return Vec3<typename promote<S, T>::type>(scalar/v[0], scalar/v[1], scalar/v[2]);
 }
 
-/// Returns V, where \f$V_i = v_i / scalar\f$ for \f$i \in [0, 2]\f$
+/// Divide each element of the given vector by @a scalar and return the result.
 template <typename S, typename T>
 inline Vec3<typename promote<S, T>::type> operator/(const Vec3<T> &v, S scalar)
 {
@@ -532,7 +533,7 @@ inline Vec3<typename promote<S, T>::type> operator/(const Vec3<T> &v, S scalar)
     return result;
 }
 
-/// Returns V, where \f$V_i = v0_i / v1_i\f$ for \f$i \in [0, 2]\f$
+/// Divide corresponding elements of @a v0 and @a v1 and return the result.
 template <typename T0, typename T1>
 inline Vec3<typename promote<T0, T1>::type> operator/(const Vec3<T0> &v0, const Vec3<T1> &v1)
 {
@@ -540,7 +541,7 @@ inline Vec3<typename promote<T0, T1>::type> operator/(const Vec3<T0> &v0, const
     return result;
 }
 
-/// Returns V, where \f$V_i = v0_i + v1_i\f$ for \f$i \in [0, 2]\f$
+/// Add corresponding elements of @a v0 and @a v1 and return the result.
 template <typename T0, typename T1>
 inline Vec3<typename promote<T0, T1>::type> operator+(const Vec3<T0> &v0, const Vec3<T1> &v1)
 {
@@ -549,7 +550,7 @@ inline Vec3<typename promote<T0, T1>::type> operator+(const Vec3<T0> &v0, const
     return result;
 }
 
-/// Returns V, where \f$V_i = v_i + scalar\f$ for \f$i \in [0, 2]\f$
+/// Add @a scalar to each element of the given vector and return the result.
 template <typename S, typename T>
 inline Vec3<typename promote<S, T>::type> operator+(const Vec3<T> &v, S scalar)
 {
@@ -558,7 +559,7 @@ inline Vec3<typename promote<S, T>::type> operator+(const Vec3<T> &v, S scalar)
     return result;
 }
 
-/// Returns V, where \f$V_i = v0_i - v1_i\f$ for \f$i \in [0, 2]\f$
+/// Subtract corresponding elements of @a v0 and @a v1 and return the result.
 template <typename T0, typename T1>
 inline Vec3<typename promote<T0, T1>::type> operator-(const Vec3<T0> &v0, const Vec3<T1> &v1)
 {
@@ -567,7 +568,7 @@ inline Vec3<typename promote<T0, T1>::type> operator-(const Vec3<T0> &v0, const
     return result;
 }
 
-/// Returns V, where \f$V_i = v_i - scalar\f$ for \f$i \in [0, 2]\f$
+/// Subtract @a scalar from each element of the given vector and return the result.
 template <typename S, typename T>
 inline Vec3<typename promote<S, T>::type> operator-(const Vec3<T> &v, S scalar)
 {
@@ -672,10 +673,10 @@ inline Vec3<T> Exp(Vec3<T> v) { return v.exp(); }
 template <typename T>
 inline Vec3<T> Log(Vec3<T> v) { return v.log(); }
 
-typedef Vec3<int32_t>   Vec3i;
-typedef Vec3<uint32_t>  Vec3ui;
-typedef Vec3<float>     Vec3s;
-typedef Vec3<double>    Vec3d;
+using Vec3i = Vec3<int32_t>;
+using Vec3ui = Vec3<uint32_t>;
+using Vec3s = Vec3<float>;
+using Vec3d = Vec3<double>;
 
 } // namespace math
 } // namespace OPENVDB_VERSION_NAME
@@ -683,6 +684,6 @@ typedef Vec3<double>    Vec3d;
 
 #endif // OPENVDB_MATH_VEC3_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
