@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -127,7 +127,7 @@ public:
     enum Flag {
         TRANSIENT = 0x1,            /// by default not written to disk
         HIDDEN = 0x2,               /// hidden from UIs or iterators
-        OUTOFCORE = 0x4,            /// data not yet loaded from disk
+        OUTOFCORE = 0x4,            /// data not yet loaded from disk (deprecated flag as of ABI=5)
         CONSTANTSTRIDE = 0x8,       /// stride size does not vary in the array
         STREAMING = 0x10            /// streaming mode collapses attributes when first accessed
     };
@@ -297,6 +297,10 @@ protected:
     uint8_t mFlags = 0;
     uint8_t mSerializationFlags = 0;
 
+#if OPENVDB_ABI_VERSION_NUMBER >= 5
+    tbb::atomic<Index32> mOutOfCore = 0; // interpreted as bool
+#endif
+
     /// used for out-of-core, paged reading
     compression::PageHandle::Ptr mPageHandle;
 }; // class AttributeArray
@@ -904,7 +908,7 @@ TypedAttributeArray<ValueType_, Codec_>::TypedAttributeArray(const TypedAttribut
 
 
 template<typename ValueType_, typename Codec_>
-typename TypedAttributeArray<ValueType_, Codec_>::TypedAttributeArray&
+TypedAttributeArray<ValueType_, Codec_>&
 TypedAttributeArray<ValueType_, Codec_>::operator=(const TypedAttributeArray& rhs)
 {
     if (&rhs != this) {
@@ -1359,7 +1363,11 @@ template<typename ValueType_, typename Codec_>
 bool
 TypedAttributeArray<ValueType_, Codec_>::isOutOfCore() const
 {
+#if OPENVDB_ABI_VERSION_NUMBER >= 5
+    return mOutOfCore;
+#else
     return (mFlags & OUTOFCORE);
+#endif
 }
 
 
@@ -1367,8 +1375,12 @@ template<typename ValueType_, typename Codec_>
 void
 TypedAttributeArray<ValueType_, Codec_>::setOutOfCore(const bool b)
 {
+#if OPENVDB_ABI_VERSION_NUMBER >= 5
+    mOutOfCore = b;
+#else
     if (b) mFlags = static_cast<uint8_t>(mFlags | OUTOFCORE);
     else   mFlags = static_cast<uint8_t>(mFlags & ~OUTOFCORE);
+#endif
 }
 
 
@@ -1579,7 +1591,11 @@ TypedAttributeArray<ValueType_, Codec_>::writeMetadata(std::ostream& os, bool ou
 {
     if (!outputTransient && this->isTransient())    return;
 
+#if OPENVDB_ABI_VERSION_NUMBER >= 5
+    uint8_t flags(mFlags);
+#else
     uint8_t flags(mFlags & uint8_t(~OUTOFCORE));
+#endif
     uint8_t serializationFlags(0);
     Index size(mSize);
     Index stride(mStrideOrTotalSize);
@@ -1746,7 +1762,11 @@ TypedAttributeArray<ValueType_, Codec_>::doLoadUnsafe(const bool compression) co
 
     // clear all write and out-of-core flags
 
+#if OPENVDB_ABI_VERSION_NUMBER >= 5
+    self->mOutOfCore = false;
+#else
     self->mFlags &= uint8_t(~OUTOFCORE);
+#endif
     self->mSerializationFlags &= uint8_t(~WRITEUNIFORM & ~WRITEMEMCOMPRESS & ~WRITEPAGED);
 }
 
@@ -2047,6 +2067,6 @@ AttributeWriteHandle<ValueType, CodecType>::set(Index index, const ValueType& va
 
 #endif // OPENVDB_POINTS_ATTRIBUTE_ARRAY_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
